_**by Edgar Allan Poe**  
(published 1839)_

    

    _Son coeur est un luth suspendu;  
    Sitot qu'on le touche il resonne.  
                                  -De Beranger._  
  
DURING the whole of a dull, dark, and soundless day in the autumn of the year, when the clouds hung oppressively low in the heavens, I had been passing alone, on horseback, through a singularly dreary tract of country; and at length found myself, as the shades of the evening drew on, within view of the melancholy House of Usher. I know not how it was --but, with the first glimpse of the building, a sense of insufferable gloom pervaded my spirit. I say insufferable; for the feeling was unrelieved by any of that half-pleasurable, because poetic, sentiment, with which the mind usually receives even the sternest natural images of the desolate or terrible. I looked upon the scene before me --upon the mere house, and the simple landscape features of the domain --upon the bleak walls --upon the vacant eye-like windows --upon a few rank sedges --and upon a few white trunks of decayed trees --with an utter depression of soul which I can compare to no earthly sensation more properly than to the after-dream of the reveller upon opium --the bitter lapse into everyday life --the hideous dropping off of the veil. There was an iciness, a sinking, a sickening of the heart --an unredeemed dreariness of thought which no goading of the imagination could torture into aught of the sublime. What was it --I paused to think --what was it that so unnerved me in the contemplation of the House of Usher? It was a mystery all insoluble; nor could I grapple with the shadowy fancies that crowded upon me as I pondered. I was forced to fall back upon the unsatisfactory conclusion, that while, beyond doubt, there are combinations of very simple natural objects which have the power of thus affecting us, still the analysis of this power lies among considerations beyond our depth. It was possible, I reflected, that a mere different arrangement of the particulars of the scene, of the details of the picture, would be sufficient to modify, or perhaps to annihilate its capacity for sorrowful impression; and, acting upon this idea, I reined my horse to the precipitous brink of a black and lurid tarn that lay in unruffled lustre by the dwelling, and gazed down --but with a shudder even more thrilling than before --upon the remodelled and inverted images of the gray sedge, and the ghastly tree-stems, and the vacant and eye-like windows.  
  
Nevertheless, in this mansion of gloom I now proposed to myself a sojourn of some weeks. Its proprietor, Roderick Usher, had been one of my boon companions in boyhood; but many years had elapsed since our last meeting. A letter, however, had lately reached me in a distant part of the country --a letter from him --which, in its wildly importunate nature, had admitted of no other than a personal reply. The MS. gave evidence of nervous agitation. The writer spoke of acute bodily illness --of a mental disorder which oppressed him --and of an earnest desire to see me, as his best, and indeed his only personal friend, with a view of attempting, by the cheerfulness of my society, some alleviation of his malady. It was the manner in which all this, and much more, was said --it the apparent heart that went with his request --which allowed me no room for hesitation; and I accordingly obeyed forthwith what I still considered a very singular summons.  
  
Although, as boys, we had been even intimate associates, yet I really knew little of my friend. His reserve had been always excessive and habitual. I was aware, however, that his very ancient family had been noted, time out of mind, for a peculiar sensibility of temperament, displaying itself, through long ages, in many works of exalted art, and manifested, of late, in repeated deeds of munificent yet unobtrusive charity, as well as in a passionate devotion to the intricacies, perhaps even more than to the orthodox and easily recognisable beauties, of musical science. I had learned, too, the very remarkable fact, that the stem of the Usher race, all time-honoured as it was, had put forth, at no period, any enduring branch; in other words, that the entire family lay in the direct line of descent, and had always, with very trifling and very temporary variation, so lain. It was this deficiency, I considered, while running over in thought the perfect keeping of the character of the premises with the accredited character of the people, and while speculating upon the possible influence which the one, in the long lapse of centuries, might have exercised upon the other --it was this deficiency, perhaps, of collateral issue, and the consequent undeviating transmission, from sire to son, of the patrimony with the name, which had, at length, so identified the two as to merge the original title of the estate in the quaint and equivocal appellation of the "House of Usher" --an appellation which seemed to include, in the minds of the peasantry who used it, both the family and the family mansion.  
  
I have said that the sole effect of my somewhat childish experiment --that of looking down within the tarn --had been to deepen the first singular impression. There can be no doubt that the consciousness of the rapid increase of my superstition --for why should I not so term it? --served mainly to accelerate the increase itself. Such, I have long known, is the paradoxical law of all sentiments having terror as a basis. And it might have been for this reason only, that, when I again uplifted my eyes to the house itself, from its image in the pool, there grew in my mind a strange fancy --a fancy so ridiculous, indeed, that I but mention it to show the vivid force of the sensations which oppressed me. I had so worked upon my imagination as really to believe that about the whole mansion and domain there hung an atmosphere peculiar to themselves and their immediate vicinity-an atmosphere which had no affinity with the air of heaven, but which had reeked up from the decayed trees, and the gray wall, and the silent tarn --a pestilent and mystic vapour, dull, sluggish, faintly discernible, and leaden-hued.  
  
Shaking off from my spirit what must have been a dream, I scanned more narrowly the real aspect of the building. Its principal feature seemed to be that of an excessive antiquity. The discoloration of ages had been great. Minute fungi overspread the whole exterior, hanging in a fine tangled web-work from the eaves. Yet all this was apart from any extraordinary dilapidation. No portion of the masonry had fallen; and there appeared to be a wild inconsistency between its still perfect adaptation of parts, and the crumbling condition of the individual stones. In this there was much that reminded me of the specious totality of old wood-work which has rotted for long years in some neglected vault, with no disturbance from the breath of the external air. Beyond this indication of extensive decay, however, the fabric gave little token of instability. Perhaps the eye of a scrutinising observer might have discovered a barely perceptible fissure, which, extending from the roof of the building in front, made its way down the wall in a zigzag direction, until it became lost in the sullen waters of the tarn.  
  
Noticing these things, I rode over a short causeway to the house. A servant in waiting took my horse, and I entered the Gothic archway of the hall. A valet, of stealthy step, thence conducted me, in silence, through many dark and intricate passages in my progress to the studio of his master. Much that I encountered on the way contributed, I know not how, to heighten the vague sentiments of which I have already spoken. While the objects around me --while the carvings of the ceilings, the sombre tapestries of the walls, the ebon blackness of the floors, and the phantasmagoric armorial trophies which rattled as I strode, were but matters to which, or to such as which, I had been accustomed from my infancy --while I hesitated not to acknowledge how familiar was all this --I still wondered to find how unfamiliar were the fancies which ordinary images were stirring up. On one of the staircases, I met the physician of the family. His countenance, I thought, wore a mingled expression of low cunning and perplexity. He accosted me with trepidation and passed on. The valet now threw open a door and ushered me into the presence of his master.  
  
The room in which I found myself was very large and lofty. The windows were long, narrow, and pointed, and at so vast a distance from the black oaken floor as to be altogether inaccessible from within. Feeble gleams of encrimsoned light made their way through the trellised panes, and served to render sufficiently distinct the more prominent objects around; the eye, however, struggled in vain to reach the remoter angles of the chamber, or the recesses of the vaulted and fretted ceiling. Dark draperies hung upon the walls. The general furniture was profuse, comfortless, antique, and tattered. Many books and musical instruments lay scattered about, but failed to give any vitality to the scene. I felt that I breathed an atmosphere of sorrow. An air of stern, deep, and irredeemable gloom hung over and pervaded all.  
  
Upon my entrance, Usher arose from a sofa on which he had been lying at full length, and greeted me with a vivacious warmth which had much in it, I at first thought, of an overdone cordiality --of the constrained effort of the ennuye man of the world. A glance, however, at his countenance, convinced me of his perfect sincerity. We sat down; and for some moments, while he spoke not, I gazed upon him with a feeling half of pity, half of awe. Surely, man had never before so terribly altered, in so brief a period, as had Roderick Usher! It was with difficulty that I could bring myself to admit the identity of the wan being before me with the companion of my early boyhood. Yet the character of his face had been at all times remarkable. A cadaverousness of complexion; an eye large, liquid, and luminous beyond comparison; lips somewhat thin and very pallid, but of a surpassingly beautiful curve; a nose of a delicate Hebrew model, but with a breadth of nostril unusual in similar formations; a finely moulded chin, speaking, in its want of prominence, of a want of moral energy; hair of a more than web-like softness and tenuity; these features, with an inordinate expansion above the regions of the temple, made up altogether a countenance not easily to be forgotten. And now in the mere exaggeration of the prevailing character of these features, and of the expression they were wont to convey, lay so much of change that I doubted to whom I spoke. The now ghastly pallor of the skin, and the now miraculous lustre of the eve, above all things startled and even awed me. The silken hair, too, had been suffered to grow all unheeded, and as, in its wild gossamer texture, it floated rather than fell about the face, I could not, even with effort, connect its Arabesque expression with any idea of simple humanity.  
  
In the manner of my friend I was at once struck with an incoherence --an inconsistency; and I soon found this to arise from a series of feeble and futile struggles to overcome an habitual trepidancy --an excessive nervous agitation. For something of this nature I had indeed been prepared, no less by his letter, than by reminiscences of certain boyish traits, and by conclusions deduced from his peculiar physical conformation and temperament. His action was alternately vivacious and sullen. His voice varied rapidly from a tremulous indecision (when the animal spirits seemed utterly in abeyance) to that species of energetic concision --that abrupt, weighty, unhurried, and hollow-sounding enunciation --that leaden, self-balanced and perfectly modulated guttural utterance, which may be observed in the lost drunkard, or the irreclaimable eater of opium, during the periods of his most intense excitement.  
  
It was thus that he spoke of the object of my visit, of his earnest desire to see me, and of the solace he expected me to afford him. He entered, at some length, into what he conceived to be the nature of his malady. It was, he said, a constitutional and a family evil, and one for which he despaired to find a remedy --a mere nervous affection, he immediately added, which would undoubtedly soon pass off. It displayed itself in a host of unnatural sensations. Some of these, as he detailed them, interested and bewildered me; although, perhaps, the terms, and the general manner of the narration had their weight. He suffered much from a morbid acuteness of the senses; the most insipid food was alone endurable; he could wear only garments of certain texture; the odours of all flowers were oppressive; his eyes were tortured by even a faint light; and there were but peculiar sounds, and these from stringed instruments, which did not inspire him with horror.  
  
To an anomalous species of terror I found him a bounden slave. "I shall perish," said he, "I must perish in this deplorable folly. Thus, thus, and not otherwise, shall I be lost. I dread the events of the future, not in themselves, but in their results. I shudder at the thought of any, even the most trivial, incident, which may operate upon this intolerable agitation of soul. I have, indeed, no abhorrence of danger, except in its absolute effect --in terror. In this unnerved-in this pitiable condition --I feel that the period will sooner or later arrive when I must abandon life and reason together, in some struggle with the grim phantasm, FEAR."  
  
I learned, moreover, at intervals, and through broken and equivocal hints, another singular feature of his mental condition. He was enchained by certain superstitious impressions in regard to the dwelling which he tenanted, and whence, for many years, he had never ventured forth --in regard to an influence whose supposititious force was conveyed in terms too shadowy here to be re-stated --an influence which some peculiarities in the mere form and substance of his family mansion, had, by dint of long sufferance, he said, obtained over his spirit-an effect which the physique of the gray walls and turrets, and of the dim tarn into which they all looked down, had, at length, brought about upon the morale of his existence.  
  
He admitted, however, although with hesitation, that much of the peculiar gloom which thus afflicted him could be traced to a more natural and far more palpable origin --to the severe and long-continued illness --indeed to the evidently approaching dissolution-of a tenderly beloved sister --his sole companion for long years --his last and only relative on earth. "Her decease," he said, with a bitterness which I can never forget, "would leave him (him the hopeless and the frail) the last of the ancient race of the Ushers." While he spoke, the lady Madeline (for so was she called) passed slowly through a remote portion of the apartment, and, without having noticed my presence, disappeared. I regarded her with an utter astonishment not unmingled with dread --and yet I found it impossible to account for such feelings. A sensation of stupor oppressed me, as my eyes followed her retreating steps. When a door, at length, closed upon her, my glance sought instinctively and eagerly the countenance of the brother --but he had buried his face in his hands, and I could only perceive that a far more than ordinary wanness had overspread the emaciated fingers through which trickled many passionate tears.  
  
The disease of the lady Madeline had long baffled the skill of her physicians. A settled apathy, a gradual wasting away of the person, and frequent although transient affections of a partially cataleptical character, were the unusual diagnosis. Hitherto she had steadily borne up against the pressure of her malady, and had not betaken herself finally to bed; but, on the closing in of the evening of my arrival at the house, she succumbed (as her brother told me at night with inexpressible agitation) to the prostrating power of the destroyer; and I learned that the glimpse I had obtained of her person would thus probably be the last I should obtain --that the lady, at least while living, would be seen by me no more.  
  
For several days ensuing, her name was unmentioned by either Usher or myself: and during this period I was busied in earnest endeavours to alleviate the melancholy of my friend. We painted and read together; or I listened, as if in a dream, to the wild improvisations of his speaking guitar. And thus, as a closer and still intimacy admitted me more unreservedly into the recesses of his spirit, the more bitterly did I perceive the futility of all attempt at cheering a mind from which darkness, as if an inherent positive quality, poured forth upon all objects of the moral and physical universe, in one unceasing radiation of gloom.  
  
I shall ever bear about me a memory of the many solemn hours I thus spent alone with the master of the House of Usher. Yet I should fail in any attempt to convey an idea of the exact character of the studies, or of the occupations, in which he involved me, or led me the way. An excited and highly distempered ideality threw a sulphureous lustre over all. His long improvised dirges will ring forever in my ears. Among other things, I hold painfully in mind a certain singular perversion and amplification of the wild air of the last waltz of Von Weber. From the paintings over which his elaborate fancy brooded, and which grew, touch by touch, into vaguenesses at which I shuddered the more thrillingly, because I shuddered knowing not why; --from these paintings (vivid as their images now are before me) I would in vain endeavour to educe more than a small portion which should lie within the compass of merely written words. By the utter simplicity, by the nakedness of his designs, he arrested and overawed attention. If ever mortal painted an idea, that mortal was Roderick Usher. For me at least --in the circumstances then surrounding me --there arose out of the pure abstractions which the hypochondriac contrived to throw upon his canvas, an intensity of intolerable awe, no shadow of which felt I ever yet in the contemplation of the certainly glowing yet too concrete reveries of Fuseli.  
  
One of the phantasmagoric conceptions of my friend, partaking not so rigidly of the spirit of abstraction, may be shadowed forth, although feebly, in words. A small picture presented the interior of an immensely long and rectangular vault or tunnel, with low walls, smooth, white, and without interruption or device. Certain accessory points of the design served well to convey the idea that this excavation lay at an exceeding depth below the surface of the earth. No outlet was observed in any portion of its vast extent, and no torch, or other artificial source of light was discernible; yet a flood of intense rays rolled throughout, and bathed the whole in a ghastly and inappropriate splendour.  
  
I have just spoken of that morbid condition of the auditory nerve which rendered all music intolerable to the sufferer, with the exception of certain effects of stringed instruments. It was, perhaps, the narrow limits to which he thus confined himself upon the guitar, which gave birth, in great measure, to the fantastic character of his performances. But the fervid facility of his impromptus could not be so accounted for. They must have been, and were, in the notes, as well as in the words of his wild fantasias (for he not unfrequently accompanied himself with rhymed verbal improvisations), the result of that intense mental collectedness and concentration to which I have previously alluded as observable only in particular moments of the highest artificial excitement. The words of one of these rhapsodies I have easily remembered. I was, perhaps, the more forcibly impressed with it, as he gave it, because, in the under or mystic current of its meaning, I fancied that I perceived, and for the first time, a full consciousness on the part of Usher, of the tottering of his lofty reason upon her throne. The verses, which were entitled "The Haunted Palace," ran very nearly, if not accurately, thus:  
  
   I.  
  
   In the greenest of our valleys,  
   By good angels tenanted,  
   Once fair and stately palace --  
   Radiant palace --reared its head.  
   In the monarch Thought's dominion --  
   It stood there!  
   Never seraph spread a pinion  
   Over fabric half so fair.  
  
   II.  
  
   Banners yellow, glorious, golden,  
   On its roof did float and flow;  
   (This --all this --was in the olden  
   Time long ago)  
   And every gentle air that dallied,  
   In that sweet day,  
   Along the ramparts plumed and pallid,  
   A winged odour went away.  
  
   III.  
  
   Wanderers in that happy valley  
   Through two luminous windows saw  
   Spirits moving musically  
   To a lute's well-tuned law,  
   Round about a throne, where sitting  
   (Porphyrogene!)  
   In state his glory well befitting,  
   The ruler of the realm was seen.  
  
   IV.  
  
   And all with pearl and ruby glowing  
   Was the fair palace door,  
   Through which came flowing, flowing, flowing  
   And sparkling evermore,  
   A troop of Echoes whose sweet duty  
   Was but to sing,  
   In voices of surpassing beauty,  
   The wit and wisdom of their king.  
  
   V.  
  
   But evil things, in robes of sorrow,  
   Assailed the monarch's high estate;  
   (Ah, let us mourn, for never morrow  
   Shall dawn upon him, desolate!)  
   And, round about his home, the glory  
   That blushed and bloomed  
   Is but a dim-remembered story  
   Of the old time entombed.  
  
   VI.  
  
   And travellers now within that valley,  
   Through the red-litten windows, see  
   Vast forms that move fantastically  
   To a discordant melody;  
   While, like a rapid ghastly river,  
   Through the pale door,  
   A hideous throng rush out forever,  
   And laugh --but smile no more.  
  
I well remember that suggestions arising from this ballad led us into a train of thought wherein there became manifest an opinion of Usher's which I mention not so much on account of its novelty, (for other men have thought thus,) as on account of the pertinacity with which he maintained it. This opinion, in its general form, was that of the sentience of all vegetable things. But, in his disordered fancy, the idea had assumed a more daring character, and trespassed, under certain conditions, upon the kingdom of inorganization. I lack words to express the full extent, or the earnest abandon of his persuasion. The belief, however, was connected (as I have previously hinted) with the gray stones of the home of his forefathers. The conditions of the sentience had been here, he imagined, fulfilled in the method of collocation of these stones --in the order of their arrangement, as well as in that of the many fungi which overspread them, and of the decayed trees which stood around --above all, in the long undisturbed endurance of this arrangement, and in its reduplication in the still waters of the tarn. Its evidence --the evidence of the sentience --was to be seen, he said, (and I here started as he spoke,) in the gradual yet certain condensation of an atmosphere of their own about the waters and the walls. The result was discoverable, he added, in that silent, yet importunate and terrible influence which for centuries had moulded the destinies of his family, and which made him what I now saw him --what he was. Such opinions need no comment, and I will make none.  
  
Our books --the books which, for years, had formed no small portion of the mental existence of the invalid --were, as might be supposed, in strict keeping with this character of phantasm. We pored together over such works as the Ververt et Chartreuse of Gresset; the Belphegor of Machiavelli; the Heaven and Hell of Swedenborg; the Subterranean Voyage of Nicholas Klimm by Holberg; the Chiromancy of Robert Flud, of Jean D'Indagine, and of De la Chambre; the Journey into the Blue Distance of Tieck; and the City of the Sun of Campanella. One favourite volume was a small octavo edition of the Directorium Inquisitorum, by the Dominican Eymeric de Gironne; and there were passages in Pomponius Mela, about the old African Satyrs and AEgipans, over which Usher would sit dreaming for hours. His chief delight, however, was found in the perusal of an exceedingly rare and curious book in quarto Gothic --the manual of a forgotten church --the Vigilae Mortuorum secundum Chorum Ecclesiae Maguntinae.  
  
I could not help thinking of the wild ritual of this work, and of its probable influence upon the hypochondriac, when, one evening, having informed me abruptly that the lady Madeline was no more, he stated his intention of preserving her corpse for a fortnight, (previously to its final interment,) in one of the numerous vaults within the main walls of the building. The worldly reason, however, assigned for this singular proceeding, was one which I did not feel at liberty to dispute. The brother had been led to his resolution (so he told me) by consideration of the unusual character of the malady of the deceased, of certain obtrusive and eager inquiries on the part of her medical men, and of the remote and exposed situation of the burial-ground of the family. I will not deny that when I called to mind the sinister countenance of the person whom I met upon the stair case, on the day of my arrival at the house, I had no desire to oppose what I regarded as at best but a harmless, and by no means an unnatural, precaution.  
  
At the request of Usher, I personally aided him in the arrangements for the temporary entombment. The body having been encoffined, we two alone bore it to its rest. The vault in which we placed it (and which had been so long unopened that our torches, half smothered in its oppressive atmosphere, gave us little opportunity for investigation) was small, damp, and entirely without means of admission for light; lying, at great depth, immediately beneath that portion of the building in which was my own sleeping apartment. It had been used, apparently, in remote feudal times, for the worst purposes of a donjon-keep, and, in later days, as a place of deposit for powder, or some other highly combustible substance, as a portion of its floor, and the whole interior of a long archway through which we reached it, were carefully sheathed with copper. The door, of massive iron, had been, also, similarly protected. Its immense weight caused an unusually sharp grating sound, as it moved upon its hinges.  
  
Having deposited our mournful burden upon tressels within this region of horror, we partially turned aside the yet unscrewed lid of the coffin, and looked upon the face of the tenant. A striking similitude between the brother and sister now first arrested my attention; and Usher, divining, perhaps, my thoughts, murmured out some few words from which I learned that the deceased and himself had been twins, and that sympathies of a scarcely intelligible nature had always existed between them. Our glances, however, rested not long upon the dead --for we could not regard her unawed. The disease which had thus entombed the lady in the maturity of youth, had left, as usual in all maladies of a strictly cataleptical character, the mockery of a faint blush upon the bosom and the face, and that suspiciously lingering smile upon the lip which is so terrible in death. We replaced and screwed down the lid, and, having secured the door of iron, made our way, with toll, into the scarcely less gloomy apartments of the upper portion of the house.  
  
And now, some days of bitter grief having elapsed, an observable change came over the features of the mental disorder of my friend. His ordinary manner had vanished. His ordinary occupations were neglected or forgotten. He roamed from chamber to chamber with hurried, unequal, and objectless step. The pallor of his countenance had assumed, if possible, a more ghastly hue --but the luminousness of his eye had utterly gone out. The once occasional huskiness of his tone was heard no more; and a tremulous quaver, as if of extreme terror, habitually characterized his utterance. There were times, indeed, when I thought his unceasingly agitated mind was labouring with some oppressive secret, to divulge which he struggled for the necessary courage. At times, again, I was obliged to resolve all into the mere inexplicable vagaries of madness, for I beheld him gazing upon vacancy for long hours, in an attitude of the profoundest attention, as if listening to some imaginary sound. It was no wonder that his condition terrified-that it infected me. I felt creeping upon me, by slow yet certain degrees, the wild influences of his own fantastic yet impressive superstitions.  
  
It was, especially, upon retiring to bed late in the night of the seventh or eighth day after the placing of the lady Madeline within the donjon, that I experienced the full power of such feelings. Sleep came not near my couch --while the hours waned and waned away. I struggled to reason off the nervousness which had dominion over me. I endeavoured to believe that much, if not all of what I felt, was due to the bewildering influence of the gloomy furniture of the room --of the dark and tattered draperies, which, tortured into motion by the breath of a rising tempest, swayed fitfully to and fro upon the walls, and rustled uneasily about the decorations of the bed. But my efforts were fruitless. An irrepressible tremour gradually pervaded my frame; and, at length, there sat upon my very heart an incubus of utterly causeless alarm. Shaking this off with a gasp and a struggle, I uplifted myself upon the pillows, and, peering earnestly within the intense darkness of the chamber, hearkened --I know not why, except that an instinctive spirit prompted me --to certain low and indefinite sounds which came, through the pauses of the storm, at long intervals, I knew not whence. Overpowered by an intense sentiment of horror, unaccountable yet unendurable, I threw on my clothes with haste (for I felt that I should sleep no more during the night), and endeavoured to arouse myself from the pitiable condition into which I had fallen, by pacing rapidly to and fro through the apartment.  
  
I had taken but few turns in this manner, when a light step on an adjoining staircase arrested my attention. I presently recognised it as that of Usher. In an instant afterward he rapped, with a gentle touch, at my door, and entered, bearing a lamp. His countenance was, as usual, cadaverously wan --but, moreover, there was a species of mad hilarity in his eyes --an evidently restrained hysteria in his whole demeanour. His air appalled me --but anything was preferable to the solitude which I had so long endured, and I even welcomed his presence as a relief.  
  
"And you have not seen it?" he said abruptly, after having stared about him for some moments in silence --"you have not then seen it? --but, stay! you shall." Thus speaking, and having carefully shaded his lamp, he hurried to one of the casements, and threw it freely open to the storm.  
  
The impetuous fury of the entering gust nearly lifted us from our feet. It was, indeed, a tempestuous yet sternly beautiful night, and one wildly singular in its terror and its beauty. A whirlwind had apparently collected its force in our vicinity; for there were frequent and violent alterations in the direction of the wind; and the exceeding density of the clouds (which hung so low as to press upon the turrets of the house) did not prevent our perceiving the life-like velocity with which they flew careering from all points against each other, without passing away into the distance. I say that even their exceeding density did not prevent our perceiving this --yet we had no glimpse of the moon or stars --nor was there any flashing forth of the lightning. But the under surfaces of the huge masses of agitated vapour, as well as all terrestrial objects immediately around us, were glowing in the unnatural light of a faintly luminous and distinctly visible gaseous exhalation which hung about and enshrouded the mansion.  
  
"You must not --you shall not behold this!" said I, shudderingly, to Usher, as I led him, with a gentle violence, from the window to a seat. "These appearances, which bewilder you, are merely electrical phenomena not uncommon --or it may be that they have their ghastly origin in the rank miasma of the tarn. Let us close this casement; --the air is chilling and dangerous to your frame. Here is one of your favourite romances. I will read, and you shall listen; --and so we will pass away this terrible night together."  
  
The antique volume which I had taken up was the "Mad Trist" of Sir Launcelot Canning; but I had called it a favourite of Usher's more in sad jest than in earnest; for, in truth, there is little in its uncouth and unimaginative prolixity which could have had interest for the lofty and spiritual ideality of my friend. It was, however, the only book immediately at hand; and I indulged a vague hope that the excitement which now agitated the hypochondriac, might find relief (for the history of mental disorder is full of similar anomalies) even in the extremeness of the folly which I should read. Could I have judged, indeed, by the wild over-strained air of vivacity with which he hearkened, or apparently hearkened, to the words of the tale, I might well have congratulated myself upon the success of my design.  
  
I had arrived at that well-known portion of the story where Ethelred, the hero of the Trist, having sought in vain for peaceable admission into the dwelling of the hermit, proceeds to make good an entrance by force. Here, it will be remembered, the words of the narrative run thus:  
  
"And Ethelred, who was by nature of a doughty heart, and who was now mighty withal, on account of the powerfulness of the wine which he had drunken, waited no longer to hold parley with the hermit, who, in sooth, was of an obstinate and maliceful turn, but, feeling the rain upon his shoulders, and fearing the rising of the tempest, uplifted his mace outright, and, with blows, made quickly room in the plankings of the door for his gauntleted hand; and now pulling there-with sturdily, he so cracked, and ripped, and tore all asunder, that the noise of the dry and hollow-sounding wood alarumed and reverberated throughout the forest.  
  
At the termination of this sentence I started, and for a moment, paused; for it appeared to me (although I at once concluded that my excited fancy had deceived me) --it appeared to me that, from some very remote portion of the mansion, there came, indistinctly, to my ears, what might have been, in its exact similarity of character, the echo (but a stifled and dull one certainly) of the very cracking and ripping sound which Sir Launcelot had so particularly described. It was, beyond doubt, the coincidence alone which had arrested my attention; for, amid the rattling of the sashes of the casements, and the ordinary commingled noises of the still increasing storm, the sound, in itself, had nothing, surely, which should have interested or disturbed me. I continued the story:  
  
"But the good champion Ethelred, now entering within the door, was sore enraged and amazed to perceive no signal of the maliceful hermit; but, in the stead thereof, a dragon of a scaly and prodigious demeanour, and of a fiery tongue, which sate in guard before a palace of gold, with a floor of silver; and upon the wall there hung a shield of shining brass with this legend enwritten --  
  
   Who entereth herein, a conqueror hath bin;  
   Who slayeth the dragon, the shield he shall win.  
  
And Ethelred uplifted his mace, and struck upon the head of the dragon, which fell before him, and gave up his pesty breath, with a shriek so horrid and harsh, and withal so piercing, that Ethelred had fain to close his ears with his hands against the dreadful noise of it, the like whereof was never before heard."  
  
Here again I paused abruptly, and now with a feeling of wild amazement --for there could be no doubt whatever that, in this instance, I did actually hear (although from what direction it proceeded I found it impossible to say) a low and apparently distant, but harsh, protracted, and most unusual screaming or grating sound --the exact counterpart of what my fancy had already conjured up for the dragon's unnatural shriek as described by the romancer.  
  
Oppressed, as I certainly was, upon the occurrence of the second and most extraordinary coincidence, by a thousand conflicting sensations, in which wonder and extreme terror were predominant, I still retained sufficient presence of mind to avoid exciting, by any observation, the sensitive nervousness of my companion. I was by no means certain that he had noticed the sounds in question; although, assuredly, a strange alteration had, during the last few minutes, taken place in his demeanour. From a position fronting my own, he had gradually brought round his chair, so as to sit with his face to the door of the chamber; and thus I could but partially perceive his features, although I saw that his lips trembled as if he were murmuring inaudibly. His head had dropped upon his breast --yet I knew that he was not asleep, from the wide and rigid opening of the eye as I caught a glance of it in profile. The motion of his body, too, was at variance with this idea --for he rocked from side to side with a gentle yet constant and uniform sway. Having rapidly taken notice of all this, I resumed the narrative of Sir Launcelot, which thus proceeded:  
  
"And now, the champion, having escaped from the terrible fury of the dragon, bethinking himself of the brazen shield, and of the breaking up of the enchantment which was upon it, removed the carcass from out of the way before him, and approached valorously over the silver pavement of the castle to where the shield was upon the wall; which in sooth tarried not for his full coming, but fell down at his feet upon the silver floor, with a mighty great and terrible ringing sound."  
  
No sooner had these syllables passed my lips, than --as if a shield of brass had indeed, at the moment, fallen heavily upon a floor of silver, became aware of a distinct, hollow, metallic, and clangorous, yet apparently muffled reverberation. Completely unnerved, I leaped to my feet; but the measured rocking movement of Usher was undisturbed. I rushed to the chair in which he sat. His eyes were bent fixedly before him, and throughout his whole countenance there reigned a stony rigidity. But, as I placed my hand upon his shoulder, there came a strong shudder over his whole person; a sickly smile quivered about his lips; and I saw that he spoke in a low, hurried, and gibbering murmur, as if unconscious of my presence. Bending closely over him, I at length drank in the hideous import of his words.  
  
"Not hear it? --yes, I hear it, and have heard it. Long --long --long --many minutes, many hours, many days, have I heard it --yet I dared not --oh, pity me, miserable wretch that I am! --I dared not --I dared not speak! We have put her living in the tomb! Said I not that my senses were acute? I now tell you that I heard her first feeble movements in the hollow coffin. I heard them --many, many days ago --yet I dared not --I dared not speak! And now --to-night --Ethelred --ha! ha! --the breaking of the hermit's door, and the death-cry of the dragon, and the clangour of the shield! --say, rather, the rending of her coffin, and the grating of the iron hinges of her prison, and her struggles within the coppered archway of the vault! Oh whither shall I fly? Will she not be here anon? Is she not hurrying to upbraid me for my haste? Have I not heard her footstep on the stair? Do I not distinguish that heavy and horrible beating of her heart? MADMAN!" here he sprang furiously to his feet, and shrieked out his syllables, as if in the effort he were giving up his soul --"MADMAN! I TELL YOU THAT SHE NOW STANDS WITHOUT THE DOOR!"  
  
As if in the superhuman energy of his utterance there had been found the potency of a spell --the huge antique panels to which the speaker pointed, threw slowly back, upon the instant, ponderous and ebony jaws. It was the work of the rushing gust --but then without those doors there DID stand the lofty and enshrouded figure of the lady Madeline of Usher. There was blood upon her white robes, and the evidence of some bitter struggle upon every portion of her emaciated frame. For a moment she remained trembling and reeling to and fro upon the threshold, then, with a low moaning cry, fell heavily inward upon the person of her brother, and in her violent and now final death-agonies, bore him to the floor a corpse, and a victim to the terrors he had anticipated.  
  
From that chamber, and from that mansion, I fled aghast. The storm was still abroad in all its wrath as I found myself crossing the old causeway. Suddenly there shot along the path a wild light, and I turned to see whence a gleam so unusual could have issued; for the vast house and its shadows were alone behind me. The radiance was that of the full, setting, and blood-red moon which now shone vividly through that once barely-discernible fissure of which I have before spoken as extending from the roof of the building, in a zig-zag direction, to the base. While I gazed, this fissure rapidly widened --there came a fierce breath of the whirlwind --the entire orb of the satellite burst at once upon my sight --my brain reeled as I saw the mighty walls rushing asunder --there was a long tumultuous shouting sound like the voice of a thousand waters --and the deep and dank tarn at my feet closed sullenly and silently over the fragments of the "HOUSE OF USHER."